@@ -17,9 +17,11 @@ from servicecatalog_puppet.commands import graph as graph_commands
 from servicecatalog_puppet.commands import management as management_commands
 from servicecatalog_puppet.commands import manifest as manifest_commands
 from servicecatalog_puppet.commands import misc as misc_commands
+from servicecatalog_puppet.commands import show_pipelines as show_pipelines_commands
 from servicecatalog_puppet.commands import orgs as orgs_commands
 from servicecatalog_puppet.commands import spoke_management as spoke_management_commands
 from servicecatalog_puppet.commands import version as version_commands
+from servicecatalog_puppet.commands import show_codebuilds as show_codebuilds_commands
 
 
 @click.group()
@@ -491,6 +493,16 @@ def version():
     version_commands.version()
 
 
+@cli.command()
+@click.option(
+    "--filter", type=click.Choice(["none", "single-runs", "full-runs"]), default="none"
+)
+@click.option("--format", type=click.Choice(["csv", "json"]), default="csv")
+@click.option("--limit", type=click.INT, default=20)
+def show_codebuilds(filter, format, limit):
+    show_codebuilds_commands.show_codebuilds(filter, limit, format)
+
+
 @cli.command()
 @click.argument("p", type=click.Path(exists=True))
 def upload_config(p):
@@ -626,5 +638,13 @@ def wait_for_parameterised_run_to_complete(on_complete_url):
         sys.exit(1)
 
 
+@cli.command()
+@click.option(
+    "--format", "-f", type=click.Choice(["table", "json", "html"]), default="table"
+)
+def show_pipelines(format):
+    show_pipelines_commands.show_pipelines(format)
+
+
 if __name__ == "__main__":
     cli()
